@@ -1,5 +1,5 @@
-axisIntervals <- function(side=1, atTick1=monthBegin.5, atTick2=monthEnd.5,
-              atLabels=monthMid, labels=month.abb, cex.axis=0.9, ...)
+axisIntervals <- function(side=1, atTick1=fda::monthBegin.5, atTick2=fda::monthEnd.5,
+              atLabels=fda::monthMid, labels=month.abb, cex.axis=0.9, ...)
 {
 #  Here's something trivial ...
 # 1.  Interval start
@@ -11,8 +11,8 @@ axisIntervals <- function(side=1, atTick1=monthBegin.5, atTick2=monthEnd.5,
        cex.axis=cex.axis, ...)
 }
 
-axesIntervals <- function(side=1:2, atTick1=monthBegin.5,
-                          atTick2=monthEnd.5, atLabels=monthMid,
+axesIntervals <- function(side=1:2, atTick1=fda::monthBegin.5,
+                          atTick2=fda::monthEnd.5, atLabels=fda::monthMid,
                           labels=month.abb, cex.axis=0.9, las=1, ...)
 {
   axisIntervals(side[1], atTick1=atTick1, atTick2=atTick2,
